/* BdfServer - Copyright (c) 2015-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.ui.options;

import fr.exemole.bdfserver.api.ui.options.ValueUiOption;


/**
 *
 * @author Vincent Calame
 */
public class ValueUiOptionBuilder {

    private String defaultValue = "";

    public ValueUiOptionBuilder() {

    }

    public ValueUiOptionBuilder(ValueUiOption valueUiOption) {
        this.defaultValue = valueUiOption.getDefaultValue();
    }

    public ValueUiOptionBuilder setDefaultValue(String defaultValue) {
        if (defaultValue == null) {
            this.defaultValue = "";
        } else {
            this.defaultValue = defaultValue;
        }
        return this;
    }

    public ValueUiOption toValueUiOption() {
        return new InternalValueUiOption(defaultValue);
    }

    public static ValueUiOptionBuilder init() {
        return new ValueUiOptionBuilder();
    }

    public static ValueUiOptionBuilder init(ValueUiOption valueUiOption) {
        return new ValueUiOptionBuilder(valueUiOption);
    }


    private static class InternalValueUiOption implements ValueUiOption {

        private final String defaultValue;

        public InternalValueUiOption(String defaultValue) {
            this.defaultValue = defaultValue;
        }

        @Override
        public String getDefaultValue() {
            return defaultValue;
        }

    }

}
